@@ -34,8 +34,14 @@
 #include "eibclient.h"
 #include "objectcontroller.h"
 #include "ruleserver.h"
+#include "services.h"
 #include "timermanager.h"
-#include "server.h"
+#include "xmlserver.h"
+#include "smsgateway.h"
+
+extern "C" {
+#include "common.h"
+}
 
 /** structure to store the arguments */
 struct arguments
@@ -138,8 +144,7 @@ main (int ac, char *ag[])
 
   RuleServer* rules = RuleServer::instance();
   ObjectController* objects = ObjectController::instance();
-  TimerManager* timers = TimerManager::instance();
-  ExceptionDays* exceptionDays = ExceptionDays::instance();
+  Services* services = Services::instance();
   try
   {
   	// Load a document
@@ -147,10 +152,11 @@ main (int ac, char *ag[])
     doc.LoadFile();
 
     ticpp::Element* pConfig = doc.FirstChildElement("config");
+
+    ticpp::Element* pServices = pConfig->FirstChildElement("services");
+    services->importXml(pServices);
     ticpp::Element* pObjects = pConfig->FirstChildElement("objects");
     objects->importXml(pObjects);
-    ticpp::Element* pExceptionDays = pConfig->FirstChildElement("exceptiondays");
-    exceptionDays->importXml(pExceptionDays);
     ticpp::Element* pRules = pConfig->FirstChildElement("rules");
     rules->importXml(pRules);
   }
@@ -169,10 +175,7 @@ main (int ac, char *ag[])
   signal (SIGINT, SIG_IGN);
   signal (SIGTERM, SIG_IGN);
 
-  timers->startManager();
-  objects->startServer();
-  Server* server = new Server(1028);
-//  Server server("/tmp/server.sock");
+  services->start();
   int x;
   pth_sigwait (&t1, &x);
 
@@ -181,20 +184,22 @@ main (int ac, char *ag[])
   {
   	// Save a document
 	  ticpp::Document doc;
-    doc.LinkEndChild(new ticpp::Declaration("1.0", "", ""));
+    ticpp::Declaration decl("1.0", "", "");
+    doc.LinkEndChild(&decl);
 
-    ticpp::Element* pConfig = new ticpp::Element("config");
-    ticpp::Element* pObjects = new ticpp::Element("objects");
-    objects->exportXml(pObjects);
-    pConfig->LinkEndChild(pObjects);
-    ticpp::Element* pExceptionDays = new ticpp::Element("exceptiondays");
-    exceptionDays->exportXml(pExceptionDays);
-    pConfig->LinkEndChild(pExceptionDays);
-    ticpp::Element* pRules = new ticpp::Element("rules");
-    rules->exportXml(pRules);
-    pConfig->LinkEndChild(pRules);
+    ticpp::Element pConfig("config");
 
-    doc.LinkEndChild(pConfig);
+    ticpp::Element pServices("services");
+    services->exportXml(&pServices);
+    pConfig.LinkEndChild(&pServices);
+    ticpp::Element pObjects("objects");
+    objects->exportXml(&pObjects);
+    pConfig.LinkEndChild(&pObjects);
+    ticpp::Element pRules("rules");
+    rules->exportXml(&pRules);
+    pConfig.LinkEndChild(&pRules);
+
+    doc.LinkEndChild(&pConfig);
     doc.SaveFile("lastconfig.xml");
   }
   catch( ticpp::Exception& ex )
@@ -211,12 +216,9 @@ main (int ac, char *ag[])
   if (arg.pidfile)
     unlink (arg.pidfile);
 
-  timers->stopManager();
+  Services::reset();
   RuleServer::reset();
   ObjectController::reset();
-  TimerManager::reset();
-  ExceptionDays::reset();
-  delete server;
 
   pth_exit (0);
   return 0;
