@@ -20,6 +20,7 @@
 #include "objectcontroller.h"
 #include "persistentstorage.h"
 #include "services.h"
+#include <cmath>
 extern "C" {
 #include "common.h"
 }
@@ -40,6 +41,8 @@ Object* Object::create(const std::string& type)
     return new ValueObject();
   else if (type == "EIS6")
     return new ScalingObject();
+  else if (type == "EIS2")
+    return new DimmingObject();
   else
     return new SwitchingObject();
 }
@@ -69,6 +72,8 @@ void Object::importXml(ticpp::Element* pConfig)
   if (gad != "")
     gad_m = readgaddr(gad.c_str());
 
+  forcewrite_m = (pConfig->GetAttribute("forcewrite") == "true");
+
   initValue_m = pConfig->GetAttribute("init");
   if (initValue_m != "" && initValue_m != "request") {
 		std::istringstream val(initValue_m);
@@ -114,20 +119,30 @@ void Object::exportXml(ticpp::Element* pConfig)
     if (initValue_m != "")
         pConfig->SetAttribute("init", initValue_m);
 
+    if (forcewrite_m)
+        pConfig->SetAttribute("forcewrite", "true");
+
     if (descr_m != "")
         pConfig->SetText(descr_m);
 }
 
 void Object::read()
 {
-  uint8_t buf[2] = { 0, 0 };
-  Services::instance()->getKnxConnection()->write(getGad(), buf, 2);
+  KnxConnection* con = Services::instance()->getKnxConnection();
+  if (!readPending_m)
+  {
+    uint8_t buf[2] = { 0, 0 };
+    con->write(getGad(), buf, 2);
+  }
   readPending_m = true;
 
 	int cnt = 0;
   while (cnt < 100 && readPending_m)
   {
-    pth_usleep(10000);
+    if (con->isRunning())
+      con->checkInput();
+    else
+      pth_usleep(10000);
     ++cnt;
   }
 }
@@ -198,7 +213,7 @@ void SwitchingObject::setFloatValue(float value)
 
 void SwitchingObject::setBoolValue(bool value)
 {
-    if (!init_m || value != value_m)
+    if (!init_m || value != value_m || forcewrite_m)
     {
         value_m = value;
         uint8_t buf[3] = { 0, 0x80 };
@@ -209,6 +224,61 @@ void SwitchingObject::setBoolValue(bool value)
     }
 }
 
+DimmingObject::DimmingObject() : value_m(0)
+{
+}
+
+DimmingObject::~DimmingObject()
+{
+}
+
+void DimmingObject::exportXml(ticpp::Element* pConfig)
+{
+    Object::exportXml(pConfig);
+    pConfig->SetAttribute("type", "EIS2");
+}
+
+void DimmingObject::onWrite(const uint8_t* buf, int len)
+{
+    int newValue;
+    Object::onWrite(buf, len);
+    if (len == 2)
+        newValue = (buf[1] & 0x3F);
+    else
+        newValue = buf[2];
+
+    if (!init_m || newValue != value_m)
+    {
+        std::cout << "New value " << newValue << " for dimming object " << getID() << std::endl;
+        value_m = newValue;
+        init_m = true;
+        onUpdate();
+    }
+}
+
+void DimmingObject::setIntValue(int value)
+{
+    if (!init_m || value != value_m || forcewrite_m)
+    {
+        value_m = value;
+        uint8_t buf[3] = { 0, 0x80 };
+        buf[1] = (value & 0x0f) | 0x80;
+        Services::instance()->getKnxConnection()->write(getGad(), buf, 2);
+
+        init_m = true;
+        onUpdate();
+    }
+}
+
+void DimmingObject::setFloatValue(float value)
+{
+    setIntValue((int)value);
+}
+
+void DimmingObject::setBoolValue(bool value)
+{
+    setFloatValue(value ? 1 : 0);
+}
 
 ValueObject::ValueObject() : value_m(0)
 {
@@ -235,6 +305,8 @@ void ValueObject::onWrite(const uint8_t* buf, int len)
     Object::onWrite(buf, len);
     int d1 = ((unsigned char) buf[2]) * 256 + (unsigned char) buf[3];
     int m = d1 & 0x7ff;
+    if (d1 & 0x8000)
+        m |= ~0x7ff;
     int ex = (d1 & 0x7800) >> 11;
     newValue = ((float)m * (1 << ex) / 100);
 //		printf ("d1=%d;m=%d;ex=%d;temp=%f\n", d1, m, ex, temp);
@@ -254,24 +326,30 @@ void ValueObject::setIntValue(int value)
 
 void ValueObject::setFloatValue(float value)
 {
-    if (value != value_m)
+    if (!init_m || value != value_m || forcewrite_m)
     {
         value_m = value;
         uint8_t buf[4] = { 0, 0x80, 0, 0 };
         int ex = 0;
-        int m = (int)(value * 100);
-        while (m > 2047 || m < -2048)
-        {
-            m >> 1;
-            ex++;
-        }
+        int m = (int)rint(value * 100);
         if (m < 0)
         {
-            m += 2048;
+            m = -m;
+            while (m > 2048)
+            {
+                m = m >> 1;
+                ex++;
+            }
+            m = -m;
             buf[2] = ((m >> 8) & 0x07) | ((ex << 3) & 0x78) | (1 << 7);
         }
         else
         {
+            while (m > 2047)
+            {
+                m = m >> 1;
+                ex++;
+            }
             buf[2] = ((m >> 8) & 0x07) | ((ex << 3) & 0x78);
         }
         buf[3] = (m & 0xff);
@@ -321,7 +399,7 @@ void ScalingObject::onWrite(const uint8_t* buf, int len)
 
 void ScalingObject::setIntValue(int value)
 {
-    if (value != value_m)
+    if (!init_m || value != value_m || forcewrite_m)
     {
         value_m = value;
         uint8_t buf[3] = { 0, 0x80, 0 };
