@@ -63,6 +63,7 @@ public:
     virtual bool getBoolValue() { return false; };
 protected:
     bool init_m;
+    bool forcewrite_m;
 private:
     std::string id_m;
     eibaddr_t gad_m;
@@ -88,6 +89,25 @@ private:
     bool value_m;
 };
 
+class DimmingObject : public Object
+{
+public:
+    DimmingObject();
+    virtual ~DimmingObject();
+
+    virtual void exportXml(ticpp::Element* pConfig);
+
+    virtual void onWrite(const uint8_t* buf, int len);
+    virtual void setIntValue(int value);
+    virtual void setFloatValue(float value);
+    virtual void setBoolValue(bool value);
+    virtual int getIntValue() { if (!init_m) read(); return value_m; };
+    virtual float getFloatValue() { return getIntValue(); };
+    virtual bool getBoolValue() { return getIntValue() != 0; };
+private:
+    int value_m;
+};
+
 class ValueObject : public Object
 {
 public:
