@@ -250,15 +250,30 @@ void DimUpAction::exportXml(ticpp::Element* pConfig)
 void DimUpAction::Run (pth_sem_t * stop)
 {
     pth_sleep(delay_m);
-    std::cout << "Execute DimUpAction" << std::endl;
+    if (stop_m > start_m) {
+        std::cout << "Execute DimUpAction" << std::endl;
 
-		unsigned long step = duration_m * 8333;
-	  for (int idx=start_m; idx < stop_m; idx++) {
-        object_m->setIntValue(idx);
-        pth_usleep(step);
-        if (object_m->getIntValue() < idx) {
-            std::cout << "Abort DimUpAction" << std::endl;
-            return;
+        unsigned long step = ((duration_m * 1000) / (stop_m - start_m)) * 1000;
+        for (int idx=start_m; idx < stop_m; idx++) {
+            object_m->setIntValue(idx);
+            pth_usleep(step);
+            if (object_m->getIntValue() < idx) {
+                std::cout << "Abort DimUpAction" << std::endl;
+                return;
+            }
+        }
+    }
+    else {
+        std::cout << "Execute DimUpAction (decrease)" << std::endl;
+
+        unsigned long step = ((duration_m * 1000) / (start_m - stop_m)) * 1000;
+        for (int idx=start_m; idx > stop_m; idx--) {
+            object_m->setIntValue(idx);
+            pth_usleep(step);
+            if (object_m->getIntValue() > idx) {
+                std::cout << "Abort DimUpAction" << std::endl;
+                return;
+            }
         }
     }
 }
