@@ -185,8 +185,12 @@ void PeriodicTask::onTimer(time_t time)
     value_m = !value_m;
     if (cl_m)
         cl_m->onChange(0);
-    if (during_m == 0)
+    if (during_m == 0 && value_m)
+    {
         value_m = false;
+        if (cl_m)
+            cl_m->onChange(0);
+    }
 }
   
 void PeriodicTask::reschedule(time_t now)
