@@ -105,8 +105,9 @@ private:
 class TimerManager : protected Thread
 {
 public:
-    static TimerManager* instance();
-    static void reset() { if (instance_m) delete instance_m; instance_m = 0; };
+    TimerManager();
+    virtual ~TimerManager();
+
     void addTask(TimerTask* task);
     void removeTask(TimerTask* task);
 
@@ -114,14 +115,10 @@ public:
     void stopManager() { Stop(); };
 
 private:
-    TimerManager();
-    virtual ~TimerManager();
-
     void Run (pth_sem_t * stop);
 
     typedef std::list<TimerTask*> TaskList_t;
     TaskList_t taskList_m;
-    static TimerManager* instance_m;
 };
 
 class DaySpec
@@ -140,8 +137,9 @@ public:
 class ExceptionDays
 {
 public:
-    static ExceptionDays* instance();
-    static void reset() { if (instance_m) delete instance_m; instance_m = 0; };
+    ExceptionDays();
+    virtual ~ExceptionDays();
+
     void addDay(DaySpec* date);
     void removeDay(DaySpec* date);
 
@@ -151,9 +149,6 @@ public:
     bool isException(time_t time);
 
 private:
-    ExceptionDays();
-    virtual ~ExceptionDays();
-
     typedef std::list<DaySpec*> DaysList_t;
     DaysList_t daysList_m;
     static ExceptionDays* instance_m;
